# object.reduce [![NPM version](https://badge.fury.io/js/object.reduce.svg)](http://badge.fury.io/js/object.reduce)


> Reduces an object to a value that is the accumulated result of running each property in the object through a callback. Executes the callback function once for each own enumerable property in the object, receiving four arguments: the initial value (or value from the previous callback call), the `value` of the current property, the `key` of the current property, and the `object` over which the function is iterating. Node.js/JavaScript utility.

## Install
#### Install with [npm](npmjs.org)

```bash
npm i object.reduce --save
```
#### Install with [bower](https://github.com/bower/bower)

```bash
bower install object.reduce --save
```

## Run tests

```bash
npm test
```

## Usage

A callback function is executed once for each own enumerable property in the object, receiving four arguments:

  - `acc`: the initial value (or value from the previous callback call),
  - `value`: the of the current property,
  - `key`: the of the current property, and
  - the original `object` over which the function is iterating.

**Example**

```js
var reduce = require('reduce-object');
var a = {a: 'foo', b: 'bar', c: 'baz'};

reduce(a, function (acc, value, key, obj) {
  acc[key] = value.toUpperCase();
  return acc;
}, {});

//=> {a: 'FOO', b: 'BAR', c: 'BAZ'};
```

## Author

**Jon Schlinkert**
 
+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert) 

## License
Copyright (c) 2014 Jon Schlinkert, contributors.  
Released under the MIT license

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on October 07, 2014._